/*
Wait counter.  When receives a "1", begin counting.  If ever receive "0", 
    reset.  When counter is greater than threshold, output "1".  
    If counter is less than threshold, output "0".
    Threshold defined by model rate (in Hz) and wait time (in seconds)

datIn[0] = Trigger  (should be 1 or 0, connected to a trigger part)
datIn[1] = WaitTime (how many seconds to wait after receiving a 1 
                     before outputting a 1)

datOut[0] = delayed trigger
 */

void wait(double *datIn, int nIn, double *datOut, int nOut)
{
  static int isFirst = 1;
  double trigger;
  double WaitTime;
  double ModelRate;
  static double counter;
  double threshold;

  trigger = datIn[0];
  WaitTime  = datIn[1];
  ModelRate = FE_RATE;

  threshold = WaitTime * ModelRate;

  if (isFirst) { // Initialize counter for first run
    isFirst = 0;
    counter = 0;
  }
  
  if (trigger == 0) // If trigger goes Low, reset the counter
    counter = 0;
  else              // Otherwise, if trigger is High, count up
    if (counter <= threshold)
      counter++;
  
  if (counter > threshold)
    datOut[0] = trigger;
  else
    datOut[0] = 0;
  

}  // end of wait()
